@@ -20,9 +20,8 @@ from multiprocessing import cpu_count
 
 logger = logging.getLogger('giza.config.runtime')
 
-from giza.tools.command import CommandError
-
-from giza.config.base import ConfigurationBase
+from giza.core.git import GitError
+from giza.config.base import ConfigurationBase, ConfigurationError
 from giza.config.sphinx_config import avalible_sphinx_builders
 
 class RuntimeStateConfigurationBase(ConfigurationBase):
@@ -32,7 +31,10 @@ class RuntimeStateConfigurationBase(ConfigurationBase):
 
     @property
     def conf(self):
-        return self._conf
+        if self._conf is None:
+            raise ConfigurationError
+        else:
+            return self._conf
 
     @conf.setter
     def conf(self, value):
@@ -183,11 +185,12 @@ class RuntimeStateConfigurationBase(ConfigurationBase):
             raise OSError(m)
 
 class RuntimeStateConfig(RuntimeStateConfigurationBase):
-    _option_registry = [ 'serial', 'length', 'days_to_save', 'builder_to_delete',
-                         'git_branch', 'git_sign_patch', 'serial_sphinx', 'package_path',
-                         'clean_generated', 'include_mask', 'push_targets', 'dry_run',
-                         't_corpora_config', 't_translate_config', 't_output_file',
-                         't_source', 't_target']
+    _option_registry = [ 'serial', 'length', 'days_to_save',
+                         'builder_to_delete', 'git_branch',
+                         'git_sign_patch', 'serial_sphinx', 'package_path',
+                         'clean_generated', 'include_mask', 'push_targets',
+                         'dry_run', 't_corpora_config', 't_translate_config',
+                         't_output_file', 't_source', 't_target']
 
     def __init__(self, obj=None):
         super(RuntimeStateConfig, self).__init__(obj)
@@ -245,7 +248,7 @@ class RuntimeStateConfig(RuntimeStateConfigurationBase):
         else:
             try:
                 data = self.conf.git.repo.branch_file(path=fn, branch='master')
-            except CommandError:
+            except GitError:
                 logger.critical('giza not configured to work with buildbot repos')
                 self._branch_conf = {}
                 return
@@ -256,6 +259,19 @@ class RuntimeStateConfig(RuntimeStateConfigurationBase):
     def builder(self):
         if 'builder' not in self.state:
             return [ ]
+        elif 'publish' in self.state['builder']:
+            self.state['builder'].remove('publish')
+
+            if 'integration' in self.conf.system.files.data:
+                targets = self.conf.system.files.data.integration['base']['targets']
+                self.state['builder'].extend(set([ target.split('-')[0] for target in targets
+                                                   if '/' not in target and
+                                                   not target.startswith('htaccess') ]))
+                return self.state['builder']
+            else:
+                m = 'Builder integration not specified for "publish" target'
+                logger.error(m)
+                raise TypeError(m)
         else:
             return self.state['builder']
 
@@ -363,3 +379,17 @@ class RuntimeStateConfig(RuntimeStateConfigurationBase):
             self.state['t_input_files'] = value
         else:
             self.state['t_input_files'] = []
+
+    @property
+    def quickstart_git(self):
+        if 'quickstart_git' in self.state:
+            return self.state['quickstart_git']
+        else:
+            return False
+
+    @quickstart_git.setter
+    def quickstart_git(self, value):
+        if isinstance(value, bool):
+            self.state['quickstart_git'] = value
+        else:
+            self.state['quickstart_git'] = bool(value)
