@@ -24,7 +24,8 @@ from giza.config.pdfs import PdfConfig
 from giza.config.intersphinx import IntersphinxConfig
 from giza.config.translate import TranslateConfig
 from giza.config.corpora import CorporaConfig
-from giza.serialization import ingest_yaml_list
+from giza.config.redirects import HtaccessData
+from giza.tools.serialization import ingest_yaml_list
 
 class SystemConfig(RecursiveConfigurationBase):
     @property
@@ -172,6 +173,8 @@ class SystemConfigData(RecursiveConfigurationBase):
     ## There shouldn't be any setters in this class. All items in this class
     ## must exist in SystemConfigPaths() objects.
 
+    _always_list_configs = ('manpages', 'pdfs', 'htaccess', 'push')
+
     def __init__(self, obj, conf):
         super(SystemConfigData, self).__init__(None, conf)
         for fn in self.conf.system.files.paths:
@@ -188,20 +191,33 @@ class SystemConfigData(RecursiveConfigurationBase):
             return object.__getattribute__(self, key)
         except AttributeError as e:
             if key in self._option_registry:
+                if isinstance(key, dict):
+                    basename, fn = key.items()[0]
+                else:
+                    fn = key
+                    basename = os.path.splitext(fn)[0]
+
                 if isinstance(self.state[key], list):
-                    return self.state[key]
+                    pass
                 elif isinstance(self.state[key], dict):
                     if len(self.state[key]) == 1:
-                        self._load_file(self.state[key])
-                    else:
-                        return self.state[key]
+                        basename, fns = self.state[key].items()[0]
+                        if isinstance(fns, list):
+                            for fn in fns:
+                                self._load_file(basename, fn)
+                        else:
+                            self._load_file(basename, fn)
                 else:
-                    self._load_file(self.state[key])
+                    self._load_file(basename, self.state[key])
 
-                return self.state[key]
+                if len(self.state[key]) == 1 and key not in self._always_list_configs:
+                    return self.state[key][0]
+                else:
+                     return self.state[key]
             else:
                 m = 'key "{0}" in system.data object does not exist'.format(key)
-                logger.debug(m)
+                if not key.startswith('__'):
+                    logger.debug(m)
                 raise AttributeError(m)
 
     def __contains__(self, value):
@@ -212,16 +228,49 @@ class SystemConfigData(RecursiveConfigurationBase):
         # it, but we want this class to load data lazily.
         pass
 
-    def _load_file(self, fn):
-        if isinstance(fn, dict):
-            if len(fn) > 1:
-                raise TypeError
-            else:
-                key, fn = fn.items()[0]
-                basename = key
-        else:
-            basename = os.path.splitext(fn)[0]
+    def _load_file(self, basename, fn):
+        full_path = self._resolve_config_path(fn)
 
+        if basename not in self.state:
+            if os.path.isfile(full_path):
+                # TODO we should make this process lazy with a more custom getter/setter
+                self.state[basename] = self._resolve_config_data(full_path, basename)
+                logger.debug('set sub-config {0} with data from {0}'.format(basename, full_path))
+            else:
+                self.state[basename] = []
+                logger.warning('{0} does not exist. continuing.'.format(full_path))
+        else:
+            if os.path.isfile(full_path):
+                d = self._resolve_config_data(full_path, basename)
+            else: #if os.path.isfile(self.state[basename]):
+                full_path = self.state[basename].items()[0][1]
+                d = self._resolve_config_data(self._resolve_config_path(full_path), basename)
+
+            self._set_config_data(basename, fn, d)
+
+    def keys(self):
+        return self._option_registry
+
+    def _set_config_data(self, basename, fn, d):
+        if isinstance(self.state[basename], list):
+            if isinstance(d, list):
+                self.state[basename].extend(d)
+            else:
+                self.state[basename].append(d)
+        else:
+            if isinstance(self.state[basename], (ConfigurationBase, dict)) and len(self.state[basename]) == 1:
+                self.state[basename] = []
+            elif self.state[basename] != fn:
+                self.state[basename] = [self.state[basename]]
+            else:
+                self.state[basename] = []
+
+            if isinstance(d, list):
+                self.state[basename].extend(d)
+            else:
+                self.state[basename].append(d)
+
+    def _resolve_config_path(self, fn):
         if os.path.exists(fn):
             full_path = fn
         elif os.path.exists(os.path.join(os.getcwd(), fn)):
@@ -232,16 +281,7 @@ class SystemConfigData(RecursiveConfigurationBase):
             full_path = os.path.join(self.conf.paths.projectroot,
                                      self.conf.paths.builddata, fn)
 
-        if os.path.exists(full_path):
-            # TODO we should make this process lazy with a more custom getter/setter
-            self.state[basename] = self._resolve_config_data(full_path, basename)
-            logger.debug('set sub-config {0} with data from {0}'.format(basename, full_path))
-        else:
-            self.state[basename] = []
-            logger.warning('{0} does not exist. continuing.'.format(full_path))
-
-    def keys(self):
-        return self._option_registry
+        return full_path
 
     def _resolve_config_data(self, fn, basename):
         logger.debug('resolving config data from file ' + fn)
@@ -256,14 +296,24 @@ class SystemConfigData(RecursiveConfigurationBase):
                 'manpages': ManpageConfig,
                 'pdfs': PdfConfig,
                 'intersphinx': IntersphinxConfig,
+                'corpora': CorporaConfig,
+            }
+            # recur_mapping for config objects that subclass RecursiveConfigurationBase
+            recur_mapping = {
                 'translate': TranslateConfig,
-                'corpora': CorporaConfig
             }
 
             if basename in mapping:
                 data = [ mapping[basename](doc) for doc in data ]
+            elif basename in recur_mapping:
+                data = [ recur_mapping[basename](doc, self.conf) for doc in data ]
+            elif basename == 'htaccess':
+                l = HtaccessData()
+                l.conf = self.conf
+                l.extend(data)
+                data = l
 
-            if len(data) == 1 and basename not in ('manpages', 'pdfs'):
+            if len(data) == 1 and basename not in self._always_list_configs:
                 return data[0]
             else:
                 return data
