@@ -21,11 +21,10 @@ logger = logging.getLogger('giza.content.images')
 from docutils.core import publish_parts
 from rstcloth.rstcloth import RstCloth
 
-from giza.command import command
-
-from giza.files import verbose_remove
-from giza.strings import dot_concat
-from giza.serialization import ingest_yaml_list
+from giza.tools.command import command
+from giza.tools.files import verbose_remove
+from giza.tools.serialization import ingest_yaml_list
+from giza.tools.strings import dot_concat
 
 ## Internal Supporting Methods
 
@@ -66,6 +65,7 @@ def generate_image_pages(dir, name, alt, output, conf):
                         '{6}</div>' ]
             img_str = ''.join(img_tags)
 
+
             r.directive('only', 'website and not html', wrap=False, block=b)
             r.newline()
             r.directive(name='raw', arg='html',
